#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
checkopenbgpd
------------------------------
Check OpenBGPD sessions Nagios|Icinga|shinken|etc plugin

"""

__docformat__ = 'restructuredtext en'

from .checkopenbgpd import main  # NOQA

# vim:set et sts=4 ts=4 tw=80:
